@@ -88,11 +88,12 @@ bool MonitorPrivate::processNotification(const NotificationMessage & msg)
   if ( msg.type() == NotificationMessage::Item ) {
     notifyCollectionStatisticsWatchers( msg.parentCollection(), msg.resource() );
     if ( !mItemFetchScope.isEmpty() &&
-          ( msg.operation() == NotificationMessage::Add || msg.operation() == NotificationMessage::Move ) ) {
+          ( msg.operation() == NotificationMessage::Add || msg.operation() == NotificationMessage::Move ||
+            msg.operation() == NotificationMessage::Remove + 1 ) ) { // ### Link, change when protocol lib is releaded in the next version
       Item item( msg.uid() );
       item.setRemoteId( msg.remoteId() );
 
-      ItemCollectionFetchJob *job = new ItemCollectionFetchJob( item, msg.parentCollection(), q_ptr );
+      ItemCollectionFetchJob *job = new ItemCollectionFetchJob( item, msg.parentCollection(), msg.parentDestCollection(), q_ptr );
       job->setFetchScope( mItemFetchScope );
       pendingJobs.insert( job, msg );
       QObject::connect( job, SIGNAL(result(KJob*)), q_ptr, SLOT(slotItemJobFinished(KJob*)) );
@@ -204,7 +205,14 @@ void MonitorPrivate::emitItemNotification( const NotificationMessage &msg, const
     case NotificationMessage::Remove:
       emit q_ptr->itemRemoved( it );
       break;
+    case NotificationMessage::Remove + 1: // ### change as soon as the new protocol lib is released, NotificationMessage::Link
+      emit q_ptr->itemLinked( it, col );
+      break;
+    case NotificationMessage::Remove + 2: // ### change as soon as the new protocol lib is released, NotificationMessage::Unlink
+      emit q_ptr->itemUnlinked( it, col );
+      break;
     default:
+      kDebug() << "Unknown operation type" << msg.operation() << "in item change notification";
       break;
   }
 }
@@ -250,6 +258,7 @@ void MonitorPrivate::slotItemJobFinished( KJob* job )
   } else {
     Item item;
     Collection col;
+    Collection destCol;
     ItemFetchJob *fetchJob = qobject_cast<ItemFetchJob*>( job );
     if ( fetchJob && fetchJob->items().count() > 0 )
       item = fetchJob->items().first();
@@ -257,8 +266,9 @@ void MonitorPrivate::slotItemJobFinished( KJob* job )
     if ( cfjob ) {
       item = cfjob->item();
       col = cfjob->collection();
+      destCol = cfjob->destCollection();
     }
-    emitItemNotification( msg, item, col );
+    emitItemNotification( msg, item, col, destCol );
   }
 }
 
@@ -286,9 +296,9 @@ void MonitorPrivate::slotCollectionJobFinished( KJob* job )
 }
 
 
-ItemCollectionFetchJob::ItemCollectionFetchJob( const Item &item, Collection::Id collectionId, QObject *parent )
+ItemCollectionFetchJob::ItemCollectionFetchJob( const Item &item, Collection::Id collectionId, Collection::Id destCollectionId, QObject *parent )
   : Job( parent ),
-    mReferenceItem( item ), mCollectionId( collectionId )
+    mReferenceItem( item ), mCollectionId( collectionId ), mDestCollectionId( destCollectionId )
 {
 }
 
@@ -306,6 +316,11 @@ Collection ItemCollectionFetchJob::collection() const
   return mCollection;
 }
 
+Collection ItemCollectionFetchJob::destCollection() const
+{
+  return mDestCollection;
+}
+
 void ItemCollectionFetchJob::setFetchScope( const ItemFetchScope &fetchScope )
 {
   mFetchScope = fetchScope;
@@ -317,6 +332,13 @@ void ItemCollectionFetchJob::doStart()
   connect( listJob, SIGNAL( result( KJob* ) ), SLOT( collectionJobDone( KJob* ) ) );
   addSubjob( listJob );
 
+  if ( mDestCollectionId > 0 ) {
+    CollectionFetchJob *destListJob = new CollectionFetchJob( Collection( mDestCollectionId ), CollectionFetchJob::Base, this );
+    connect( destListJob, SIGNAL( result( KJob* ) ), SLOT( destCollectionJobDone( KJob* ) ) );
+    addSubjob( destListJob );
+  }
+
+
   ItemFetchJob *fetchJob = new ItemFetchJob( mReferenceItem, this );
   fetchJob->setFetchScope( mFetchScope );
   connect( fetchJob, SIGNAL( result( KJob* ) ), SLOT( itemJobDone( KJob* ) ) );
@@ -335,6 +357,18 @@ void ItemCollectionFetchJob::collectionJobDone( KJob* job )
   }
 }
 
+void ItemCollectionFetchJob::destCollectionJobDone( KJob* job )
+{
+  if ( !job->error() ) {
+    CollectionFetchJob *listJob = qobject_cast<CollectionFetchJob*>( job );
+    if ( listJob->collections().isEmpty() ) {
+      setError( 1 );
+      setErrorText( QLatin1String( "No collection found" ) );
+    } else
+      mDestCollection = listJob->collections().first();
+  }
+}
+
 void ItemCollectionFetchJob::itemJobDone( KJob* job )
 {
   if ( !job->error() ) {
