@@ -212,6 +212,7 @@ CalendarResources::CalendarResources( const KDateTime::Spec &timeSpec,
   : Calendar( timeSpec ),
     d( new KCal::CalendarResources::Private( family ) )
 {
+  mPendingDeleteFromResourceMap = false;
   d->mManager->addObserver( this );
 }
 
@@ -220,6 +221,7 @@ CalendarResources::CalendarResources( const QString &timeZoneId,
   : Calendar( timeZoneId ),
     d( new KCal::CalendarResources::Private( family ) )
 {
+  mPendingDeleteFromResourceMap = false;
   d->mManager->addObserver( this );
 }
 
@@ -287,6 +289,7 @@ void CalendarResources::load()
   }
 
   d->mOpen = true;
+  emit calendarLoaded();
 }
 
 bool CalendarResources::reload()
@@ -439,7 +442,7 @@ bool CalendarResources::deleteEvent( Event *event )
   if ( d->mResourceMap.find( event ) != d->mResourceMap.end() ) {
     status = d->mResourceMap[event]->deleteEvent( event );
     if ( status ) {
-      d->mResourceMap.remove( event );
+      mPendingDeleteFromResourceMap = true;
     }
   } else {
     status = false;
@@ -448,6 +451,9 @@ bool CalendarResources::deleteEvent( Event *event )
       status = (*it)->deleteEvent( event ) || status;
     }
   }
+  if ( status ) {
+    notifyIncidenceDeleted( event );
+  }
 
   setModified( status );
   return status;
@@ -492,7 +498,7 @@ bool CalendarResources::deleteTodo( Todo *todo )
   if ( d->mResourceMap.find( todo ) != d->mResourceMap.end() ) {
     status = d->mResourceMap[todo]->deleteTodo( todo );
     if ( status ) {
-      d->mResourceMap.remove( todo );
+      mPendingDeleteFromResourceMap = true;
     }
   } else {
     CalendarResourceManager::ActiveIterator it;
@@ -638,7 +644,7 @@ bool CalendarResources::deleteJournal( Journal *journal )
   if ( d->mResourceMap.find( journal ) != d->mResourceMap.end() ) {
     status = d->mResourceMap[journal]->deleteJournal( journal );
     if ( status ) {
-      d->mResourceMap.remove( journal );
+      mPendingDeleteFromResourceMap = true;
     }
   } else {
     CalendarResourceManager::ActiveIterator it;
@@ -839,6 +845,7 @@ bool CalendarResources::beginChange( Incidence *incidence )
     }
     d->mResourceMap[ incidence ] = r;
   }
+  mPendingDeleteFromResourceMap = false;
 
   int count = incrementChangeCount( r );
   if ( count == 1 ) {
@@ -864,6 +871,11 @@ bool CalendarResources::endChange( Incidence *incidence )
 
   int count = decrementChangeCount( r );
 
+  if ( mPendingDeleteFromResourceMap ) {
+    d->mResourceMap.remove( incidence );
+    mPendingDeleteFromResourceMap = false;
+  }
+
   if ( count == 0 ) {
     bool ok = save( d->mTickets[ r ], incidence );
     if ( ok ) {
