@@ -14,9 +14,9 @@
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *   GNU General Public License for more details.
  *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *   You should have received a copy of the GNU General Public License along
+ *   with this program; if not, write to the Free Software Foundation, Inc.,
+ *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  *   Send comments and bug fixes to jcorey@fruity.ath.cx
  *
@@ -56,8 +56,8 @@ imap://server/folder/
  *  ERR_DOES_NOT_EXIST is reserved for folders.
  */
 
-#include "imap4.h"
 #include <kdepimlibs-compat.h> // for KDE_signal, remove in KDEPIM 4.2
+#include "imap4.h"
 
 #include <QByteArray>
 #include <QList>
@@ -319,7 +319,7 @@ IMAP4Protocol::get (const KUrl & _url)
       {
         // get the MIME header and fill getLastHandled()
         QString mySection = aSection;
-        mySection.replace("]", ".MIME]");
+        mySection.replace(']', ".MIME]");
         cmd = sendCommand (imapCommand::clientFetch (aSequence, mySection));
         do
         {
@@ -536,7 +536,7 @@ IMAP4Protocol::listDir (const KUrl & _url)
           UDSEntry entry;
           imapCache fake;
 
-          for (QStringList::ConstIterator it = list.begin(); it != list.end();
+          for (QStringList::ConstIterator it = list.constBegin(); it != list.constEnd();
                ++it)
           {
             fake.setUid((*it).toULong());
@@ -640,9 +640,9 @@ IMAP4Protocol::setHost (const QString & _host, quint16 _port,
     if (!myHost.isEmpty ())
       closeConnection ();
     myHost = _host;
-    if (_port == 0) 
+    if (_port == 0)
         myPort = (mySSL) ? ImapsPort : ImapPort;
-    else 
+    else
         myPort = _port;
     myUser = _user;
     myPass = _pass;
@@ -737,12 +737,9 @@ bool IMAP4Protocol::parseReadLine (QByteArray & buffer, long relay)
       }
       // append to buffer
       {
-        QBuffer stream (&buffer);
-
-        stream.open (QIODevice::WriteOnly);
-        stream.seek (buffer.size ());
-        stream.write (readBuffer, copyLen);
-        stream.close ();
+        int oldsize = buffer.size();
+        buffer.resize(oldsize + copyLen);
+        memcpy(buffer.data() + oldsize, readBuffer, copyLen);
 //        kDebug(7116) <<"appended" << copyLen <<"d got now" << buffer.size();
       }
 
@@ -1617,7 +1614,7 @@ IMAP4Protocol::specialCustomCommand( QDataStream& stream )
   if ( type == 'E' ) {
     kDebug(7116) << "IMAP4Protocol::specialCustomCommand: extended mode" << endl;
     imapCommand *cmd = sendCommand (imapCommand::clientCustom( command, QString() ));
-    while ( !parseLoop () );
+    while ( !parseLoop () ) {};
 
     // see if server is waiting
     if (!cmd->isComplete () && !getContinuation ().isEmpty ())
@@ -1640,7 +1637,7 @@ IMAP4Protocol::specialCustomCommand( QDataStream& stream )
 
     do
     {
-      while (!parseLoop ());
+      while (!parseLoop ()) {};
     }
     while (!cmd->isComplete ());
 
@@ -2040,8 +2037,8 @@ bool IMAP4Protocol::makeLogin ()
     cmd = doCommand (new imapCommand ("CAPABILITY", ""));
 
     kDebug(7116) <<"IMAP4: setHost: capability";
-    for (QStringList::Iterator it = imapCapabilities.begin ();
-         it != imapCapabilities.end (); ++it)
+    for (QStringList::const_iterator it = imapCapabilities.constBegin ();
+         it != imapCapabilities.constEnd (); ++it)
     {
       kDebug(7116) <<"'" << (*it) <<"'";
     }
@@ -2077,8 +2074,8 @@ bool IMAP4Protocol::makeLogin ()
         {
           kDebug(7116) <<"TLS mode has been enabled.";
           imapCommand *cmd2 = doCommand (new imapCommand ("CAPABILITY", ""));
-          for (QStringList::Iterator it = imapCapabilities.begin ();
-                                     it != imapCapabilities.end (); ++it)
+          for (QStringList::const_iterator it = imapCapabilities.constBegin ();
+                                     it != imapCapabilities.constEnd (); ++it)
           {
             kDebug(7116) <<"'" << (*it) <<"'";
           }
