@@ -1846,8 +1846,8 @@ imapParser::parseURL (const KUrl & _url, QString & _box, QString & _section,
     _box.truncate( paramStart ); // strip parameters
   }
   // extract parameters
-  for (QStringList::ConstIterator it (parameters.begin ());
-       it != parameters.end (); ++it)
+  for (QStringList::ConstIterator it (parameters.constBegin ());
+       it != parameters.constEnd (); ++it)
   {
     QString temp = (*it);
 
@@ -2012,8 +2012,8 @@ bool imapParser::hasCapability (const QString & cap)
 {
   QString c = cap.toLower();
 //  kDebug(7116) <<"imapParser::hasCapability - Looking for '" << cap <<"'";
-  for (QStringList::ConstIterator it = imapCapabilities.begin ();
-       it != imapCapabilities.end (); ++it)
+  for (QStringList::ConstIterator it = imapCapabilities.constBegin ();
+       it != imapCapabilities.constEnd (); ++it)
   {
 //    kDebug(7116) <<"imapParser::hasCapability - Examining '" << (*it) <<"'";
     if ( !(kasciistricmp(c.toAscii(), (*it).toAscii())) )
@@ -2035,9 +2035,9 @@ QString imapParser::namespaceForBox( const QString & box )
   QString myNamespace;
   if ( !box.isEmpty() )
   {
-    QList<QString> list = namespaceToDelimiter.keys();
+    const QList<QString> list = namespaceToDelimiter.keys();
     QString cleanPrefix;
-    for ( QList<QString>::Iterator it = list.begin(); it != list.end(); ++it )
+    for ( QList<QString>::ConstIterator it = list.begin(); it != list.end(); ++it )
     {
       if ( !(*it).isEmpty() && box.contains( *it ) )
         return (*it);
